LOGGING_CONFIG = {
    'version': 1,
    'disable_existing_loggers': True,
    'formatters': {
        'standard': {
            'format': '%(asctime)s [%(levelname)s] %(name)s: %(message)s'
        },
    },
    'handlers': {
        'default': {
            'level': 'DEBUG',
            'formatter': 'standard',
            'class': 'logging.StreamHandler',
            'stream': 'ext://sys.stdout',  # Default is stderr
        },
    },
    'loggers': {
        '': {
            'handlers': ['default'],
            'level': 'DEBUG',
            'propagate': False
        }
    }
}



import argparse
import sys

import logging.config

import os.path

from .logger import LOGGING_CONFIG

logging.config.dictConfig(LOGGING_CONFIG)
logger = logging.getLogger(__name__)


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('--log-level', type=str, default="INFO", help="defines log level of adapter")
    parser.add_argument('--config-path', type=str, required=True, dest="config_path", help="defines the base value")
    args = parser.parse_args()

    if not os.path.isfile(args.config_path):
        logger.error(f"No such file exists: {args.config_path}")
        sys.exit()




from setuptools import setup, find_packages

with open('requirements.txt') as f:
    requirements = f.readlines()

long_description = "OpenDataDiscovery DVC Adapter"

setup(
    name='dvc-adapter',
    version='0.0.2',
    author='Provectus team',
    url='https://github.com/opendatadiscovery/odd-dvc-adapter',
    description='OpenDataDiscovery DVC Adapter.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    license='MIT',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'dvc-adapter = adapter:main'
        ]
    },
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
    install_requires=requirements,
    zip_safe=False
)